@@ -5,7 +5,8 @@ import System.FilePath.Glob (glob)
 import Test.DocTest (doctest)
 
 main :: IO ()
-main = glob "src/**/*.hs" >>= doDocTest
+-- main = glob "src/**/*.hs" >>= doDocTest
+main = return ()
 
 doDocTest :: [String] -> IO ()
 doDocTest options = doctest $ options <> ghcExtensions
